function love.load()
  shader = love.graphics.newShader( -- load the shader
  [[
    //Fragment shader
    uniform sampler2D ColorTable; // 1 x 16 pixels
    uniform sampler2D MyIndexTexture;
    varying vec2 TexCoord0;

    vec4 effect( vec4 color, Image MyIndexTexture, vec2 TexCoord0, vec2 screen_coords ){
    	//What color do we want to index?
    	vec4 myindex = texture2D(MyIndexTexture, TexCoord0);
    	//Do a dependency texture read
    	vec4 texel = texture2D(ColorTable, myindex.xy);
    	return texel;   //Output the color
    }
  ]] )

	sprite = love.graphics.newImage( 'sprite.png' ) -- load the sprite
	sprite:setFilter( 'nearest' ) 									 -- make it scale correctly

  numberOfPalettes = 0
  paletteData = love.image.newImageData( 'palettes.png' )

  coordinates = {}
  for x = 1, paletteData:getWidth() do
    local r, g, b, a = paletteData:getPixel(x - 1, 0)
    table.insert(coordinates, {x = r, y = g})
  end

  palettes = {}
  for y = 1, paletteData:getHeight() do
    numberOfPalettes = numberOfPalettes + 1
    local canvas = love.graphics.newCanvas(256, 256)
    local canvasData = canvas:newImageData()
    for x = 1, paletteData:getWidth() do
      local cx, cy = coordinates[x].x, coordinates[x].y
      local r, g, b, a = paletteData:getPixel(x - 1, y - 1)
      canvasData:setPixel(cx, cy, r, g, b, a)
    end
    local result = love.graphics.newImage(canvasData)
    result:setFilter( 'nearest' )
    table.insert(palettes, result)
  end

  currentPalette = 3
  shader:send( "ColorTable", palettes[currentPalette] )
end

function love.draw()
	love.graphics.clear(32, 99, 99)
  love.graphics.scale(4,4)

  love.graphics.setShader()				-- draw the sprite normally
	love.graphics.draw(sprite,  50, 50)

  love.graphics.setShader(shader)	-- draw the sprite with the shader applied
	love.graphics.draw(sprite, 100, 50)
end

function love.keypressed(key)
  if key == 'left' then
    currentPalette = currentPalette - 1
  elseif key == 'right' then
    currentPalette = currentPalette + 1
  end
  if currentPalette < 1 then
    currentPalette = numberOfPalettes
  elseif currentPalette > numberOfPalettes then
    currentPalette = 1
  end
  shader:send( "ColorTable", palettes[currentPalette] )
end
